*Effective* is a Python library for doing symbolic calculations in
effective field theory.

It provides the tools to create a Lagrangian and integrate out heavy
fields at the tree level. It also includes functions for applying
customizable transformations (for example, Fierz identities or
simplification using equations of motion of the light fields) to the
effective Lagrangian to simplify it or write it in terms of a chosen
effective operator basis.

Installation
============

To install Effective using `pip`_ do::

  pip install effective

The source can be downloaded from the `GitHub repository`_.

.. _pip: https://pypi.python.org/pypi/pip/

.. _GitHub repository: https://github.com/jccriado/effective
  
Documentation
=============

Read the documentation at: http://effective.readthedocs.io/en/latest/.


